changeset 14:6054f65054d5

Various priority/invisibility trigger fixes
author Matti Hamalainen <ccr@tnsp.org>
date Fri, 02 Sep 2005 22:29:54 +0000
parents d47ac03f1513
children cfeb61728e69
files ggrtf-magical.tf ggrtf.tf
diffstat 2 files changed, 78 insertions(+), 77 deletions(-) [+]
line wrap: on
line diff
--- a/ggrtf-magical.tf	Fri Sep 02 22:06:17 2005 +0000
+++ b/ggrtf-magical.tf	Fri Sep 02 22:29:54 2005 +0000
@@ -13,10 +13,10 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Spellcasting and spell-status reporting
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-/def msb = /if ({opt_rspells}=~"on") /msr #%{spell_rleft}%;/endif
+/def -i msb = /if ({opt_rrounds}=~"on") /msr #%{spell_rleft}%;/endif
 
 ;; Start of spell
-/def -ag -msimple -t"You start chanting." spell_start =\
+/def -i -p9999 -ag -msimple -t"You start chanting." spell_start =\
 	/set spell_t=$[time()]%;\
 	/set cnt_casts=$[cnt_casts + 1]%;\
 	/set spell_rfirst=on%;\
@@ -28,7 +28,7 @@
 
 
 ;; Spell done
-/def -ag -msimple -t"You are done with the chant." spell_end =\
+/def -i -p9999 -ag -msimple -t"You are done with the chant." spell_end =\
 	/set cnt_trounds=$[cnt_trounds + spell_rcount]%;\
 	/set cnt_scasts=$[cnt_scasts + 1]%;\
 	/set spell_st=off%;\
@@ -37,7 +37,7 @@
 
 
 ;; Spell failed
-/def spell_fail =\
+/def -i spell_fail =\
 /if ({spell_st2}=~"on")\
 	/set cnt_scasts=$[cnt_scasts - 1]%;\
 	/set cnt_fcasts=$[cnt_fcasts + 1]%;\
@@ -45,103 +45,103 @@
 	/endif
 
 ;; Spell fumbled
-/def spell_fumble =\
+/def -i spell_fumble =\
 /if ({spell_st2}=~"on")\
 	/set cnt_scasts=$[cnt_scasts - 1]%;\
 	/set cnt_fucasts=$[cnt_fucasts + 1]%;\
 	/set spell_st2=off%;\
 	/endif
 
-/def -aCred -mregexp -t"^You (fail miserably in your|stutter the magic words and fail the) spell.$" spell_fail1 =\
+/def -i -p9999 -aCred -mregexp -t"^You (fail miserably in your|stutter the magic words and fail the) spell.$" spell_fail1 =\
 	/spell_fail
 
-/def -aCred -mregexp -t"^You .* (spell misfires|spell fizzles).$" spell_fail2 =\
+/def -i -p9999 -aCred -mregexp -t"^You .* (spell misfires|spell fizzles).$" spell_fail2 =\
 	/spell_fail
 
-/def -aCred -mregexp -t"^You (falter and fumble the spell|stumble and lose your concentration.)" spell_fail3 =\
+/def -i -p9999 -aCred -mregexp -t"^You (falter and fumble the spell|stumble and lose your concentration.)" spell_fail3 =\
 	/spell_fail
 
-/def -aCred -mregexp -t"^Your (spell just sputters|concentration fails and so does your spell|mind plays a trick with you and you fail in your spell|concentration drifts away as you think you feel a malignant aura)." spell_fail4 =\
+/def -i -p9999 -aCred -mregexp -t"^Your (spell just sputters|concentration fails and so does your spell|mind plays a trick with you and you fail in your spell|concentration drifts away as you think you feel a malignant aura)." spell_fail4 =\
 	/spell_fail
 
-/def -aCred -msimple -t"Something touches you and spoils your concentration ruining the spell." spell_fail5 =\
+/def -i -p9999 -aCred -msimple -t"Something touches you and spoils your concentration ruining the spell." spell_fail5 =\
 	/spell_fail
 
-/def -aCred -msimple -t"The spell fails." spell_fail6 =\
+/def -i -p9999 -aCred -msimple -t"The spell fails." spell_fail6 =\
 	/spell_fail
 
 
 ;; Spell interrupted
-/def spell_interrupt =\
+/def -i spell_interrupt =\
 /if ({spell_st}=~"on")\
 	/set cnt_icasts=$[cnt_icasts + 1]%;\
 	/set spell_st=off%;\
 	/endif
 
-/def -aCred -mregexp -t"^You( interrupt|r movement prevents you from casting| have insufficient strength to cast| do not have enough spell points to cast| lose your concentration and cannot cast) the spell.$" spell_interrupt1 =\
+/def -i -p9999 -aCred -mregexp -t"^You( interrupt|r movement prevents you from casting| have insufficient strength to cast| do not have enough spell points to cast| lose your concentration and cannot cast) the spell.$" spell_interrupt1 =\
 	/spell_interrupt
 
-/def -aCred -mregexp -t"^You (get hit SO HARD that you have to stop your spell|lose your concentration and stop your spell casting|massage your wounds and forget your spell).$" spell_interrupt2 =\
+/def -i -p9999 -aCred -mregexp -t"^You (get hit SO HARD that you have to stop your spell|lose your concentration and stop your spell casting|massage your wounds and forget your spell).$" spell_interrupt2 =\
 	/spell_interrupt
 
-/def -aCred -msimple -t"The ground shakes violently! EARTHQUAKE!" spell_interrupt3 =\
+/def -i -p9999 -aCred -msimple -t"The ground shakes violently! EARTHQUAKE!" spell_interrupt3 =\
 	/spell_interrupt
 
-/def -aCred -msimple -t"You interrupt the chant in order to start a new chant." spell_interrupt4 =\
+/def -i -p9999 -aCred -msimple -t"You interrupt the chant in order to start a new chant." spell_interrupt4 =\
 	/spell_interrupt
 
 
 ;; Spell rounds
-/def -aCyellow -mregexp -t"^([A-z ]+): (#*)$" spell_status1 =\
-/set spell_rleft=$[strlen({P2})]%;\
-/if ({spell_rfirst}=~"on")\
-	/set spell_rfirst=off%;\
-	/set spell_rcount=%{spell_rleft}%;\
-	/if ({battle_st}!~"on") /msb%;/endif%;\
-	/endif%;\
-/if ({battle_st}=~"on") /msb%;/endif
+/def -i -p9999 -aCyellow -mregexp -t"^([A-z ]+): (#*)$" spell_status1 =\
+	/set spell_rleft=$[strlen({P2})]%;\
+	/if ({spell_rfirst}=~"on")\
+		/set spell_rfirst=off%;\
+		/set spell_rcount=%{spell_rleft}%;\
+		/if ({battle_st}!~"on") /msb%;/endif%;\
+		/endif%;\
+	/if ({battle_st}=~"on") /msb%;/endif
 
 
 ;; Cast burden/slow
-/def -aCgreen -msimple -t"Your heavy burden slows down your casting." spell_burden =\
-/set spell_rleft=$[spell_rleft + 1]%;\
-/set spell_rcount=$[spell_rcount + 1]%;\
-/msb%;/if ({opt_rspells}=~"on") @@emote slows down%;/endif
+/def -i -p9999 -aCgreen -msimple -t"Your heavy burden slows down your casting." spell_burden =\
+	/set spell_rleft=$[spell_rleft + 1]%;\
+	/set spell_rcount=$[spell_rcount + 1]%;\
+	/msb%;/if ({opt_rspells}=~"on") @@emote slows down%;/endif
 
 
 ;; Cast haste
-/def -aCgreen -msimple -t"You skillfully cast the spell with haste." spell_haste =\
-/set spell_rleft=$[spell_rleft - 1]%;\
-/set spell_rcount=$[spell_rcount - 1]%;\
-/set cnt_hastes=$[cnt_hastes + 1]%;\
-/msb%;/if ({opt_rspells}=~"on") @@emote hastes%;/endif
+/def -i -p9999 -aCgreen -msimple -t"You skillfully cast the spell with haste." spell_haste =\
+	/set spell_rleft=$[spell_rleft - 1]%;\
+	/set spell_rcount=$[spell_rcount - 1]%;\
+	/set cnt_hastes=$[cnt_hastes + 1]%;\
+	/msb%;/if ({opt_rspells}=~"on") @@emote hastes%;/endif
 
 
 ;; Cast greater haste
-/def -aCgreen -msimple -t"You skillfully cast the spell with greater haste." spell_ghaste =\
-/set spell_rleft=$[spell_rleft - 2]%;\
-/set spell_rcount=$[spell_rcount - 2]%;\
-/set cnt_ghastes=$[cnt_ghastes + 1]%;\
-/msb%;/if ({opt_rspells}=~"on") @@emote ghastes%;/endif
+/def -i -p9999 -aCgreen -msimple -t"You skillfully cast the spell with greater haste." spell_ghaste =\
+	/set spell_rleft=$[spell_rleft - 2]%;\
+	/set spell_rcount=$[spell_rcount - 2]%;\
+	/set cnt_ghastes=$[cnt_ghastes + 1]%;\
+	/msb%;/if ({opt_rspells}=~"on") @@emote ghastes%;/endif
 
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Miscellaneous
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-/def -aCgreen -msimple -t"You sizzle with magical energy." ent_sizzle =\
-/if ({opt_rspells}=~"on") @@emote vibrates noisily.%;/endif
+/def -i -p9999 -aCgreen -msimple -t"You sizzle with magical energy." ent_sizzle =\
+	/if ({opt_rspells}=~"on") @@emote vibrates noisily.%;/endif
 
-/def -aCgreen -msimple -t"You surreptitiously conceal your spell casting." ent_conceal =\
-/if ({opt_rspells}=~"on") @@emote conceals ...%;/endif
+/def -i -p9999 -aCgreen -msimple -t"You surreptitiously conceal your spell casting." ent_conceal =\
+	/if ({opt_rspells}=~"on") @@emote conceals ...%;/endif
 
-/def -aCgreen -msimple -t"You feel your skills in handling elemental forces improve." ent_essence =\
+/def -i -p9999 -aCgreen -msimple -t"You feel your skills in handling elemental forces improve." ent_essence =\
 	/mse gains essence!
 
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Resistances
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-/def mresist =\
+/def -i mresist =\
 	/set resist_name=%{-1}%;/set resist_str=???%;/set resist_val=???%;/set resist_col=@{BCwhite}%;\
 	/if ({1}=1)	/set resist_str=screams%; /set resist_val=0%;	/set resist_col=@{BCgreen}%;\
 	/elseif ({1}=2)	/set resist_str=writhes%; /set resist_val=20%;	/set resist_col=@{Cgreen}%;\
@@ -152,33 +152,33 @@
 	/endif%;\
 	/echo -p @{BCyellow}%{resist_name}@{n} %{resist_col}%{resist_str}@{n} (@{BCwhite}%{resist_val}%%@{n} resist)
 
-/def -ag -mregexp -t"^([A-Za-z ,.'-]+) screams in pain\.$" resist1 = /mresist 1 %{P1}
-/def -ag -mregexp -t"^([A-Za-z ,.'-]+) writhes in agony\.$" resist2 = /mresist 2 %{P1}
-/def -ag -mregexp -t"^([A-Za-z ,.'-]+) shudders from the force of the attack\.$" resist3 = /mresist 3 %{P1}
-/def -ag -mregexp -t"^([A-Za-z ,.'-]+) grunts from the pain\.$" resist4 = /mresist 4 %{P1}
-/def -ag -mregexp -t"^([A-Za-z ,.'-]+) winces a little from the pain\.$" resist5 = /mresist 5 %{P1}
-/def -ag -mregexp -t"^([A-Za-z ,.'-]+) shrugs off the attack\.$" resist6 = /mresist 6 %{P1}
+/def -i -p9999 -ag -mregexp -t"^([A-Za-z ,.'-]+) screams in pain\.$" resist1 = /mresist 1 %{P1}
+/def -i -p9999 -ag -mregexp -t"^([A-Za-z ,.'-]+) writhes in agony\.$" resist2 = /mresist 2 %{P1}
+/def -i -p9999 -ag -mregexp -t"^([A-Za-z ,.'-]+) shudders from the force of the attack\.$" resist3 = /mresist 3 %{P1}
+/def -i -p9999 -ag -mregexp -t"^([A-Za-z ,.'-]+) grunts from the pain\.$" resist4 = /mresist 4 %{P1}
+/def -i -p9999 -ag -mregexp -t"^([A-Za-z ,.'-]+) winces a little from the pain\.$" resist5 = /mresist 5 %{P1}
+/def -i -p9999 -ag -mregexp -t"^([A-Za-z ,.'-]+) shrugs off the attack\.$" resist6 = /mresist 6 %{P1}
 
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Damage criticality
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-/def -aCgreen -msimple -t'You feel like your spell gained additional power.' ent_dcrit1 =\
+/def -i -p9999 -aCgreen -msimple -t'You feel like your spell gained additional power.' ent_dcrit1 =\
 	/set cnt_damcrits=$[cnt_damcrits + 1]%;\
 	/set cnt_dcrit1=$[cnt_dcrit1 + 1]%;\
 	/mse dcrits (1)
 
-/def -aCgreen -msimple -t'You feel like you managed to channel additional POWER to your spell.' ent_dcrit2 =\
+/def -i -p9999 -aCgreen -msimple -t'You feel like you managed to channel additional POWER to your spell.' ent_dcrit2 =\
 	/set cnt_damcrits=$[cnt_damcrits + 1]%;\
 	/set cnt_dcrit2=$[cnt_dcrit2 + 1]%;\
 	/mse dcrits (2)
 
-/def -aCgreen -msimple -t'Your fingertips are surrounded with swirling ENERGY as you cast the spell.' ent_dcrit3 =\
+/def -i -p9999 -aCgreen -msimple -t'Your fingertips are surrounded with swirling ENERGY as you cast the spell.' ent_dcrit3 =\
 	/set cnt_damcrits=$[cnt_damcrits + 1]%;\
 	/set cnt_dcrit3=$[cnt_dcrit3 + 1]%;\
 	/mse dcrits (3)
 
-/def -aCgreen -msimple -t'You feel connected to the very essence of magic.' ent_dcrit4 =\
+/def -i -p9999 -aCgreen -msimple -t'You feel connected to the very essence of magic.' ent_dcrit4 =\
 	/set cnt_damcrits=$[cnt_damcrits + 1]%;\
 	/set cnt_dcrit4=$[cnt_dcrit4 + 1]%;\
 	/mse is connected to very essence of magic!
@@ -188,46 +188,46 @@
 ;; Energy Aura
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Aura weakening
-/def -aCred -msimple -t"Your aura is starting to weaken!" rec_auraweak =\
+/def -i -p9999 -aCred -msimple -t"Your aura is starting to weaken!" rec_auraweak =\
 	/set st_eaura_weak=on%;/set st_eaura_weak_t=$[time()]%;\
 	/status_update%;\
 	/msr Energy Aura WEAKENING! $[prgetstime({st_eaura_t})] / $[prgetstime({st_eaura_t2})]
 
 ;; Aura recharged
-/def -aCred -mregexp -t"^(Not all is lost, however, you did just recharge your aura|You try your hardest but cannot focus enough energy|You try to focus more magic energy into your aura but get no useful result).$" rec_aurarecharged =\
+/def -i -p9999 -aCred -mregexp -t"^(Not all is lost, however, you did just recharge your aura|You try your hardest but cannot focus enough energy|You try to focus more magic energy into your aura but get no useful result).$" rec_aurarecharged =\
 	/set st_eaura_weak=off%;\
 	/set st_eaura_t=$[time()]%;\
 	/status_update%;\
 	/msr Energy Aura Reloaded! 
 
 ;; Aura off
-/def -aCred -msimple -t"Your aura of glowing light fades to nothing." rec_aura0 =\
+/def -i -p9999 -aCred -msimple -t"Your aura of glowing light fades to nothing." rec_aura0 =\
 	/set st_eaura_weak=off%;\
 	/proff eaura
 
-;; Aura change
-/def -aCred -msimple -t"You turn your aura down a step from red to gold." rec_aurach1 =\
+;; Aura changes
+/def -i -p9999 -aCred -msimple -t"You turn your aura down a step from red to gold." rec_aurach1 =\
 	/set st_eaura=1%;/status_update
 
-/def -aCred -msimple -t"You turn your aura down a step from blue to red." rec_aurach2 =\
+/def -i -p9999 -aCred -msimple -t"You turn your aura down a step from blue to red." rec_aurach2 =\
 	/set st_eaura=2%;/status_update
 
 ;; Aura on
-/def -aCred -msimple -t"Suddenly a softly glowing aura of yellow light comes into being around you." rec_aura1 =\
+/def -i -p9999 -aCred -msimple -t"Suddenly a softly glowing aura of yellow light comes into being around you." rec_aura1 =\
 	/pron eaura [Yellow]%;\
 	/set st_eaura=1%;\
 	/set st_eaura_weak=off%;\
 	/status_update%;\
 	/set st_eaura_t2=%{st_eaura_t}
 
-/def -aCred -msimple -t"With a burst of energy, your aura changes from soft yellow to bright red." rec_aura2 =\
+/def -i -p9999 -aCred -msimple -t"With a burst of energy, your aura changes from soft yellow to bright red." rec_aura2 =\
 	/pron eaura [Red]%;\
 	/set st_eaura=2%;\
 	/set st_eaura_weak=off%;\
 	/status_update%;\
 	/set st_eaura_t2=%{st_eaura_t}
 
-/def -aCred -msimple -t"Tendrils of lightning flit around you as your aura changes from flame red to" rec_aura3 =\
+/def -i -p9999 -aCred -msimple -t"Tendrils of lightning flit around you as your aura changes from flame red to" rec_aura3 =\
 	/pron eaura [Blue]%;\
 	/set st_eaura=3%;\
 	/set st_eaura_weak=off%;\
--- a/ggrtf.tf	Fri Sep 02 22:06:17 2005 +0000
+++ b/ggrtf.tf	Fri Sep 02 22:29:54 2005 +0000
@@ -35,12 +35,13 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; /verbose	- Toggle verbosity (off = echo to client only)
 ;; /rshape	- Toggle target and shape reporting
 ;; /rspells	- Toggle spell rounds reporting
 ;; /rstat	- Toggle stat (hp/sp/ep) reporting on every combat round
+;; /pss		- Party Short Status on every combat round
 ;;
 ;; /stats	- Show various statistics
 ;; /prots	- Report current prots (see also below)
-;; /handicaps	- Report current handicaps (see also below)
 ;;
 ;; /move	- Normal movement mode
 ;; /ship	- Use keypad to control a ship instead of your character
@@ -50,7 +51,6 @@
 ;;
 ;; Special triggers:
 ;; tweak	- Report prots to 'party report'-channel or tweaker (if remote-emote)
-;; tickle	- Report handicaps ...
 ;;
 ;; /comppath		- Shows current path as compressed
 ;; /csavepath <name>	- Save compressed path as BatMUD command-alias by given name.
@@ -133,14 +133,15 @@
 	/endif
 
 ;; Toggles
-/def prtoggle = /eval /def %{1} = /if ({opt_%{1}}=~"on") /set opt_%{1}=off%%%;/else  /set opt_%{1}=on%%%;/endif%%%;/msq %{-1} = %%%{opt_%{1}}
+/def prtoggle = /eval /def %{1} = /if ({opt_%{1}}=~"on") /set opt_%{1}=off%%%;/else  /set opt_%{1}=on%%%;/endif%%%;/msq @{Cgreen}%{-1}@{n} [@{Cred}%%%{opt_%{1}}@{n}]
 
 /prtoggle verbose Verbose
-/prtoggle rshape Report Shape
-/prtoggle rspells Report Spells
+/prtoggle rshape Report shape
+/prtoggle rspells Report spells
+/prtoggle rrounds Report spell/skill rounds
 /prtoggle peer AutoPeer
-/prtoggle rstat Report Stats
-/prtoggle pss Auto Party Status
+/prtoggle rstat Report stats
+/prtoggle pss Auto party short status
 
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -285,7 +286,7 @@
 ; -k Takes parameters (implies usage of regexp patterns aka '-r')
 
 /set st_prots=
-/def prcreate =\
+/def -i prcreate =\
 	/if (!getopts("i:n:l:A:B:C:u:d:srkh", "")) /msq ERROR! Invalid prot creation command!%;/break%;/endif%;\
 	/set st_prots=%{opt_i} %{st_prots}%;\
 	/set st_%{opt_i}=0%;\
@@ -317,7 +318,7 @@
 
 
 ;; Turn prot ON
-/def pron =\
+/def -i pron =\
 	/eval /set qtval_l=$$[st_%{1}_l]%;\
 	/eval /set qtval_s=$$[st_%{1}_stack]%;\
 	/eval /set qtval_h=$$[st_%{1}_renew]%;\
@@ -348,7 +349,7 @@
 
 
 ;; Turn prot OFF
-/def proff =\
+/def -i proff =\
 	/eval /set qtval=$$[st_%{1}]%;\
 	/if ({qtval})\
 		/eval /set qtval_t=$$[st_%{1}_t]%;\
@@ -458,9 +459,9 @@
 
 ;; Report prots
 /def prots = /msq $[prots_get()]
-/def -mregexp -t"^[A-Z][A-Za-z]+ tweaks your nose (mischievously|mischeviously).$" prot_tweak1 = /msr $[prots_get()]
-/def -mregexp -t"^@([A-Z][A-Za-z]+) tweaks your nose (mischievously|mischeviously).$" prot_tweak2 = @@emoteto %{P1} $[prots_get()]
-/def -mregexp -t"^You tweak your own nose (mischievously|mischeviously).$" prot_tweak3 = /msr $[prots_get()]
+/def -i -p9999 -mregexp -t"^[A-Z][a-z]+ tweaks your nose (mischievously|mischeviously).$" prot_tweak1 = /msr $[prots_get()]
+/def -i -p9999 -mregexp -t"^@([A-Z][a-z]+) tweaks your nose (mischievously|mischeviously).$" prot_tweak2 = @@emoteto %{P1} $[prots_get()]
+/def -i -p9999 -mregexp -t"^You tweak your own nose (mischievously|mischeviously).$" prot_tweak3 = /msr $[prots_get()]
 
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -35,12 +35,13 @@
 ;; /verbose	- Toggle verbosity (off = echo to client only)
 ;; /rshape	- Toggle target and shape reporting
-;; /rspells	- Toggle spell rounds reporting
+;; /rspells	- Toggle spells reporting
+;; /rrounds	- Toggle spells/skills rounds reporting
 ;; /rstat	- Toggle stat (hp/sp/ep) reporting on every combat round